@@ -233,12 +233,11 @@ class __kdevpythondocumentation_builtin_float():
     def fromhex(self,s): return 0
 
 class __kdevpythondocumentation_builtin_int():
-    def bit_length(self): return 0
+    pass
 
 class __kdevpythondocumentation_builtin_complex():
     real = 3
     imag = 5
-    def conjugate(self): return __kdevpythondocumentation_builtin_complex()
 
 class BaseException():
     args = ()
@@ -434,3 +433,5 @@ list = __kdevpythondocumentation_builtin_list
 def exit(status): return None
 __name__ = "none"
 __file__ = "none"
+__package__ = "none"
+
